@@ -1,9 +1,10 @@
 """Main."""
 from typing import Union, List
+from types import ModuleType
 
 
 def yaml2instances(
-    loading_data: Union[dict, List[dict]], search_modules: list, **kwargs
+    loading_data: Union[dict, List[dict]], search_modules: List[ModuleType], **kwargs
 ) -> list:
     """From the list of modules, find the class written in yaml and instantiate it."""
     instance_list = []
@@ -22,13 +23,16 @@ def yaml2instances(
     return instance_list
 
 
-def _loading_data_to_instance(loading_data: dict, search_modules, **kwargs):
+def _loading_data_to_instance(
+    loading_data: dict, search_modules: List[ModuleType], **kwargs
+):
     modules_dict = {}
+    for module in search_modules:
+        _modules = module.__dict__
+        modules_dict.update(_modules)
     for _item, _kwargs in loading_data.items():
-        if _kwargs is not None:
-            kwargs.update(_kwargs)
-        for module in search_modules:
-            _modules = module.__dict__
-            modules_dict.update(_modules)
-        instance = modules_dict[_item](**(kwargs or {}))
+        base = {}
+        base.update(kwargs or {})
+        base.update(_kwargs or {})
+        instance = modules_dict[_item](**base)
         yield instance
